@@ -1,7 +1,7 @@
-#!/usr/bin/python2
+#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-#Copyright (C) 2013 Chabot Simon
+#Copyright (C) 2013 Chabot Simon, Sadaoui Akim
 
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -22,4 +22,3 @@ from fiabilipy.markov import Markovprocess
 
 __all__ = ['System', 'Component', 'Voter', 'Markovprocess']
 __version__ = '2.2'
-__author__ = 'Simon Chabot <simon.chabot@etu.utc.fr>'
